/**
 * Copyright 2006-8 Simon Andrews
 *
 *    This file is part of FRETSaw.
 *
 *    FRETSaw is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FRETSaw is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with ChIPMonk; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.FretSaw.Display;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;

import uk.ac.bbsrc.babraham.FretSaw.FretSawApplication;
import uk.ac.bbsrc.babraham.FretSaw.IO.OIBLoader;
import uk.ac.bbsrc.babraham.FretSaw.IO.TIFFLoader;
import uk.ac.bbsrc.babraham.FretSaw.Preferences.PreferencesEditor;

public class FretSawMenuBar extends JMenuBar implements ActionListener {

	private FretSawApplication application;
	
	public FretSawMenuBar (FretSawApplication application) {
	
		this.application = application;
		
		JMenu fileMenu = new JMenu("File");
		fileMenu.setMnemonic(KeyEvent.VK_F);
		
		JMenu fileOpen = new JMenu("Open");
		fileOpen.setMnemonic(KeyEvent.VK_O);
				
		JMenuItem fileOpenOIB = new JMenuItem("OIB...");
		fileOpenOIB.setActionCommand("open_oib");
		fileOpenOIB.setMnemonic(KeyEvent.VK_O);
		fileOpenOIB.addActionListener(this);
		
		fileOpen.add(fileOpenOIB);
		
		JMenuItem fileOpenTIFF = new JMenuItem("TIFF...");
		fileOpenTIFF.setActionCommand("open_tiff");
		fileOpenTIFF.setMnemonic(KeyEvent.VK_T);
		fileOpenTIFF.addActionListener(this);
		
		fileOpen.add(fileOpenTIFF);

		fileMenu.add(fileOpen);
		
		JMenuItem fileSave = new JMenuItem("Save...");
		fileSave.setMnemonic(KeyEvent.VK_S);
		fileSave.setActionCommand("save");
		fileSave.addActionListener(this);
		fileMenu.add(fileSave);
		
		fileMenu.addSeparator();
		
		JMenuItem fileExit = new JMenuItem("Exit");
		fileExit.setMnemonic(KeyEvent.VK_X);
		fileExit.setActionCommand("exit");
		fileExit.addActionListener(this);
		fileMenu.add(fileExit);
		
		add(fileMenu);
		
		JMenu editMenu = new JMenu("Edit");
		editMenu.setMnemonic(KeyEvent.VK_E);
		
		JMenuItem editPreferences = new JMenuItem("Preferences...");
		editPreferences.setMnemonic(KeyEvent.VK_P);
		editPreferences.setActionCommand("prefs");
		editPreferences.addActionListener(this);
		editMenu.add(editPreferences);
		
		add(editMenu);
		
		JMenu helpMenu = new JMenu("Help");
		helpMenu.setMnemonic(KeyEvent.VK_H);
		
		JMenuItem helpAbout = new JMenuItem("About FRETSaw");
		helpAbout.setMnemonic(KeyEvent.VK_A);
		helpAbout.setActionCommand("help_about");
		helpAbout.addActionListener(this);
		helpMenu.add(helpAbout);
		
		add(helpMenu);
		
	}

	public void actionPerformed(ActionEvent e) {

		String c = e.getActionCommand();
		
		if (c.equals("open_oib")) {
			application.openImage(new OIBLoader(application));
		}
		else if (c.equals("open_tiff")) {
			application.openImage(new TIFFLoader(application));
		}
		else if (c.equals("exit")) {
			application.dispose();
		}
		else if (c.equals("prefs")) {
			new PreferencesEditor(application);
		}
		else if (c.equals("save")) {
			application.saveImage();
		}		
		else if (c.equals("help_about")) {
			new AboutDialog(application);
		}		
	}
}
